==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/WorkMail/DeleteAccessControlRule.pm <==

package Paws::WorkMail::DeleteAccessControlRule;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);
  has OrganizationId => (is => 'ro', isa => 'Str');

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteAccessControlRule');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::WorkMail::DeleteAccessControlRuleResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::WorkMail::DeleteAccessControlRule - Arguments for method DeleteAccessControlRule on L<Paws::WorkMail>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteAccessControlRule on the
L<Amazon WorkMail|Paws::WorkMail> service. Use the attributes of this class
as arguments to method DeleteAccessControlRule.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteAccessControlRule.

=head1 SYNOPSIS

    my $workmail = Paws->service('WorkMail');
    my $DeleteAccessControlRuleResponse = $workmail->DeleteAccessControlRule(
      Name           => 'MyAccessControlRuleName',
      OrganizationId => 'MyOrganizationId',          # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/workmail/DeleteAccessControlRule>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the access control rule.



=head2 OrganizationId => Str

The identifier for the organization.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteAccessControlRule in L<Paws::WorkMail>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/WorkMail/DeleteAccessControlRule.pm <==

package Paws::WorkMail::DeleteAccessControlRule;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);
  has OrganizationId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteAccessControlRule');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::WorkMail::DeleteAccessControlRuleResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::WorkMail::DeleteAccessControlRule - Arguments for method DeleteAccessControlRule on L<Paws::WorkMail>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteAccessControlRule on the
L<Amazon WorkMail|Paws::WorkMail> service. Use the attributes of this class
as arguments to method DeleteAccessControlRule.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteAccessControlRule.

=head1 SYNOPSIS

    my $workmail = Paws->service('WorkMail');
    my $DeleteAccessControlRuleResponse = $workmail->DeleteAccessControlRule(
      Name           => 'MyAccessControlRuleName',
      OrganizationId => 'MyOrganizationId',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/workmail/DeleteAccessControlRule>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

The name of the access control rule.



=head2 B<REQUIRED> OrganizationId => Str

The identifier for the organization.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteAccessControlRule in L<Paws::WorkMail>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
